editor

package
v1.10.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 10, 2025 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetEditor added in v1.5.3

func GetEditor() string

GetEditor returns the editor to use, defaulting to vim if EDITOR is not set

func LaunchAndExit added in v1.5.3

func LaunchAndExit(scratchID string, content []byte) error

LaunchAndExit launches the editor with a file in the final location and exits immediately

func LaunchAndExitWithConfig added in v1.5.3

func LaunchAndExitWithConfig(scratchID string, content []byte, cfg *config.Config) error

LaunchAndExitWithConfig launches the editor with a file in the final location and exits immediately

func OpenInEditor

func OpenInEditor(content []byte) ([]byte, error)

func OpenInEditorWithExtension added in v1.6.2

func OpenInEditorWithExtension(content []byte, extensionHint string) ([]byte, error)

OpenInEditorWithExtension opens content in editor with optional extension hint

Types

This section is empty.

Jump to